@@ -7,7 +7,7 @@ class DummyDataset(Dataset):
     """Implementation of DummyLoader Dataset."""
 
     def get_json_schema(self):
-        """Return emptry json schema."""
+        """Return empty json schema."""
         schema = {}
         return schema
 
