@@ -104,6 +104,13 @@ def start_run(
     return _active_run
 
 
+def _add_eval_run(
+    run_id,
+):
+    """Add eval run to model version's metainfo on server. For internal use only."""
+    return request_for_function(inspect.currentframe())
+
+
 def log_model(
     artifact_path,
     action_type,  # "train"/"finetune"/"upload"
