@@ -3,14 +3,7 @@ from functools import partial
 from operator import attrgetter
 
 from ML_management import mlmanagement
-from ML_management.registry.exceptions import (
-    MetricNotLogged,
-    ModelNotRegistered,
-    NoMetricProvided,
-    UnsupportedCriteria,
-    VersionNotFound,
-)
-
+from ML_management.registry.exceptions import MetricNotLogged, ModelNotRegistered, NoMetricProvided, UnsupportedCriteria, VersionNotFound
 from mlflow.entities.model_registry.model_version import ModelVersion
 from mlflow.entities.model_registry.registered_model import RegisteredModel
 from mlflow.exceptions import RestException
@@ -59,15 +52,14 @@ class RegistryManager:
         # optimal_min parameter is to look for minimal value of metric, max by default
         current_best_version, current_best_score = None, None
         self.check_model_registered(name)
-        model_versions = self.client.search_model_versions(
-            filter_string=f"name = '{name}'"
-        )
+        # MlflowClient.search_model_versions always returns all versions in single page with no token
+        # as it uses SqlAlchemyStore on mlflow server pod based on helm Values.mlflow.backendUri
+        # which starts with "postgres". See mlflow/store/model_registry/sqlalchemy_store.py:732
+        model_versions = self.client.search_model_versions(filter_string=f"name = '{name}'")
 
         for mv in model_versions:
             try:
-                metric_value = self.client.get_run(run_id=mv.run_id).data.metrics[
-                    metric
-                ]
+                metric_value = self.client.get_run(run_id=mv.run_id).data.metrics[metric]
             except KeyError:
                 continue  # metric might not be logged for SOME versions, so don't raise straight away
 
@@ -137,9 +129,11 @@ class RegistryManager:
             PagedList[ModelVersion]: Available model versions
         """
         self.check_model_registered(name)
-        model_versions = self.client.search_model_versions(
-            filter_string=f"name = '{name}'"
-        )
+
+        # MlflowClient.search_model_versions always returns all versions in single page with no token
+        # as it uses SqlAlchemyStore on mlflow server pod based on helm Values.mlflow.backendUri
+        # which starts with "postgres". See mlflow/store/model_registry/sqlalchemy_store.py:732
+        model_versions = self.client.search_model_versions(filter_string=f"name = '{name}'")
 
         return model_versions
 
